public interface AnagramGame {
    /**
    * Submit a word on behalf of a user. A word is accepted if its letters are
    * contained in the original string submitted in the constructor, and if it
    * is in the word list at https://sites.google.com/a/ifyoucan.org/downloads/downloads/wordlist.txt.
    * If the word is accepted and its score is high enough, the submission
    * should be added to the high score list. If there are multiple submissions
    * with the same score, all are accepted, but the first submission with that
    * score should rank higher.
    *
    * @param word User's submission. All submissions may be assumed to be
    * lowercase and containing no whitespace or special
    * characters.
    */
    public void submitWord(String word);
    /**
    * Return word entry at given position in the high score list, 0 being the
    * highest (best score) and 9 the lowest. You may assume that this method
    * will never be called with position > 9.
    *
    * @param position Index on high score list
    * @return word entry at given position in the high score list, or null if
    * there is no entry at that position
    */
    String getWordEntryAtPosition(int position);
    /**
    * Return score at given position in the high score list, 0 being the
    * highest (best score) and 9 the lowest. You may assume that this method
    * will never be called with position > 9.
    *
    * @param position Index on high score list
    * @return score at given position in the high score list, or null if there* is no entry at that position
    */
    Integer getScoreAtPosition(int position);
}
